Struct TimeEvents

#[non_exhaustive]
pub struct TimeEvents { pub time_event: Vec<TimeEvent>, pub dropped_annotations_count: i32, pub dropped_message_events_count: i32, }
A collection of TimeEvents. A TimeEvent is a time-stamped annotation on the span, consisting of either user-supplied key:value pairs, or details of a message sent/received between Spans.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
time_event: Vec<TimeEvent>

A collection of TimeEvents.

dropped_annotations_count: i32

The number of dropped annotations in all the included time events. If the value is 0, then no annotations were dropped.

dropped_message_events_count: i32

The number of dropped message events in all the included time events. If the value is 0, then no message events were dropped.

Implementations

Source

impl TimeEvents

pub fn set_dropped_annotations_count<T: Into<i32>>(self, v: T) -> Self

Sets the value of dropped_annotations_count.

pub fn set_dropped_message_events_count<T: Into<i32>>(self, v: T) -> Self

Sets the value of dropped_message_events_count.

pub fn set_time_event<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<TimeEvent>,

Sets the value of time_event.