Struct MessageEvent

#[non_exhaustive]
pub struct MessageEvent { pub type: Type, pub id: i64, pub uncompressed_size_bytes: i64, pub compressed_size_bytes: i64, }
An event describing a message sent/received between Spans.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
type: Type

Type of MessageEvent. Indicates whether the message was sent or received.

id: i64

An identifier for the MessageEvent’s message that can be used to match SENT and RECEIVED MessageEvents.

uncompressed_size_bytes: i64

The number of uncompressed bytes sent or received.

compressed_size_bytes: i64

The number of compressed bytes sent or received. If missing, the compressed size is assumed to be the same size as the uncompressed size.

Implementations

Source

impl MessageEvent

pub fn set_type<T: Into<Type>>(self, v: T) -> Self

Sets the value of r#type.

pub fn set_id<T: Into<i64>>(self, v: T) -> Self

Sets the value of id.

pub fn set_uncompressed_size_bytes<T: Into<i64>>(self, v: T) -> Self

Sets the value of uncompressed_size_bytes.

pub fn set_compressed_size_bytes<T: Into<i64>>(self, v: T) -> Self

Sets the value of compressed_size_bytes.