#[non_exhaustive]pub struct Module {
pub module: Option<TruncatableString>,
pub build_id: Option<TruncatableString>,
}Expand description
Binary module.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.module: Option<TruncatableString>For example: main binary, kernel modules, and dynamic libraries such as libc.so, sharedlib.so (up to 256 bytes).
build_id: Option<TruncatableString>A unique identifier for the module, usually a hash of its contents (up to 128 bytes).
Implementations
Sourceimpl Module
impl Module
Sourcepub fn set_module<T: Into<Option<TruncatableString>>>(self, v: T) -> Self
pub fn set_module<T: Into<Option<TruncatableString>>>(self, v: T) -> Self
Sets the value of module.
Sourcepub fn set_build_id<T: Into<Option<TruncatableString>>>(self, v: T) -> Self
pub fn set_build_id<T: Into<Option<TruncatableString>>>(self, v: T) -> Self
Sets the value of build_id.