#[non_exhaustive]pub struct TruncatableString {
pub value: String,
pub truncated_byte_count: i32,
}Expand description
Represents a string that might be shortened to a specified length.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.value: StringThe shortened string. For example, if the original string is 500
bytes long and the limit of the string is 128 bytes, then
value contains the first 128 bytes of the 500-byte string.
Truncation always happens on a UTF8 character boundary. If there are multi-byte characters in the string, then the length of the shortened string might be less than the size limit.
truncated_byte_count: i32The number of bytes removed from the original string. If this value is 0, then the string was not shortened.
Implementations
Sourceimpl TruncatableString
impl TruncatableString
Sourcepub fn set_truncated_byte_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_truncated_byte_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of truncated_byte_count.