#[non_exhaustive]pub struct StackFrames {
pub frame: Vec<StackFrame>,
pub dropped_frames_count: i32,
}Expand description
A collection of stack frames, which can be truncated.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.frame: Vec<StackFrame>Stack frames in this call stack.
dropped_frames_count: i32The number of stack frames that were dropped because there were too many stack frames. If this value is 0, then no stack frames were dropped.
Implementations
Sourceimpl StackFrames
impl StackFrames
Sourcepub fn set_dropped_frames_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_dropped_frames_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of dropped_frames_count.